from sympy import isprime

class primecheck:
    @staticmethod
    def isgermainprime(n):
        # Check if n is a prime number
        if not isprime(n):
            return False
        
        # Check if 2n + 1 is also a prime number
        return isprime(2*n + 1)
    
    @staticmethod
    def isimtiazgermainprime(n):
        # Check if n is a Sophie Germain prime
        p = (n - 1) / 2
        if not isprime(n) or not isprime(p) or not isprime(2*p + 1):
            return False
        
        # Check if 2p + 1 is composite
        m = 2 * p + 1
        if isprime(m):
            return False
        
        # Check if 2(2p + 1) + 1 is prime
        q = 2 * m + 1
        return isprime(q)



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="ImtiazGermain",
    version="0.1.2",
    author="Aitzaz Imtiaz",
    author_email="aitzazimtiaz855@gmail.com",
    description="A Python library for checking if a number is a Imtiaz-Germain and Germain prime or not",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://ImtiazGermain.readthedocs.io/",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    install_requires=[
        "sympy",
    ],
)
